## Psipher

Psipher is an encryption or decryption tool based on caesar cipher methodology.

# Installation
pip install psipher
## Tool Usage
from psipher import Encrypt,Decrypt

Encrypt("Enter text")
Decrypt("Enter text")